@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright 2017-2021 Ramil Nugmanov <nougmanoff@protonmail.com>
+#  Copyright 2017-2022 Ramil Nugmanov <nougmanoff@protonmail.com>
 #  This file is part of chython.
 #
 #  chython is free software; you can redistribute it and/or modify
@@ -16,10 +16,13 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with this program; if not, see <https://www.gnu.org/licenses/>.
 #
-from .molecule import *
+from .bonds import *
 from .cgr import *
+from .molecule import *
 from .query import *
 from .reaction import *
 
 
 __all__ = [x for x in locals() if x.endswith('Container')]
+__all__.append('Bond')
+__all__.append('QueryBond')
