@@ -16,7 +16,7 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with this program; if not, see <https://www.gnu.org/licenses/>.
 #
-from ...exceptions import EmptyMolecule
+from ...exceptions import EmptyMolecule, EmptyV2000
 
 
 class EMOLRead:
@@ -63,7 +63,7 @@ class EMOLRead:
                 elif self.__parser:
                     collected = self.__record_collector(line)
                     if collected:
-                        self.__parser(collected)
+                        self.__parser(collected)  # noqa
 
                 elif line.startswith('M  V30 BEGIN ATOM'):
                     self.__parser = self.__atom_parser
@@ -91,6 +91,8 @@ class EMOLRead:
 
         elif self.__in_mol is not None:
             raise SyntaxError('invalid usage')
+        elif line.startswith('M  END'):  # ad-hoc for empy V2000
+            raise EmptyV2000
         elif not line.startswith('M  V30 BEGIN CTAB'):
             raise ValueError('invalid CTAB')
         else:
@@ -199,6 +201,8 @@ class EMOLRead:
             self.__star_points.append(n)
             self.__atoms_count -= 1
             return
+        elif a == 'R#':
+            raise ValueError('R-groups not supported')
 
         i = None
         c = 0
@@ -228,7 +232,7 @@ class EMOLRead:
             for kv in kvs:
                 k, v = kv.split('=', 1)
                 if k == 'ATOMS':
-                    a = tuple(self.__atom_map[x] for x in v[1:-1].split()[1:])
+                    a = tuple(self.__atom_map[x] for x in v[1:-1].split()[1:] if x not in self.__star_points)
                 elif k == 'FIELDNAME':
                     f = v.strip('"')
                 if k == 'FIELDDATA':
